@@ -16,6 +16,7 @@ class CatalystX::Declare::Keyword::Action
 
     use constant STOP_PARSING   => '__MXDECLARE_STOP_PARSING__';
     use constant UNDER_VAR      => '$CatalystX::Declare::SCOPE::UNDER';
+    use constant UNDER_STACK    => '@CatalystX::Declare::SCOPE::UNDER_STACK';
 
     use aliased 'CatalystX::Declare::Action::CatchValidationError';
     use aliased 'MooseX::Method::Signatures::Meta::Method';
@@ -107,7 +108,7 @@ class CatalystX::Declare::Keyword::Action
 
         if ($attributes{Private}) {
             delete $attributes{ $_ }
-                for qw( Args CaptureArgs Chained Signature Subname Action );
+                for qw( Args CaptureArgs Chained Signature Private );
         }
 
         if ($ctx->peek_next_char eq '{') {
@@ -272,8 +273,13 @@ class CatalystX::Declare::Keyword::Action
 
         if ($ctx->peek_next_char eq '{' and $self->identifier eq 'under') {
             $ctx->inject_if_block(
-                sprintf '%s; local %s; BEGIN { %s = qq(%s) };',
-                    $ctx->scope_injector_call,
+                sprintf '%s; BEGIN { push %s, %s; %s = qq(%s) };',
+                    $ctx->scope_injector_call(
+                        sprintf ';BEGIN { %s = pop %s };', 
+                            UNDER_VAR,
+                            UNDER_STACK,
+                    ),
+                    UNDER_STACK,
                     UNDER_VAR,
                     UNDER_VAR,
                     $target,
@@ -390,6 +396,10 @@ CatalystX::Declare::Keyword::Action - Declare Catalyst Actions
             # the final keyword can be used to be more 
             # visually explicit about end-points
             final action some_action { ... }
+
+            # type dispatching works
+            final action with_str (Str $x) as via_type;
+            final action with_int (Int $x) as via_type;
         }
 
         # of course you can also chain to external actions
@@ -431,6 +441,12 @@ C<get_item> method:
         $ctx->stash(item => $self->get_item);
     }
 
+=head2 Why $ctx instead of $c
+
+Some might ask why the context object is called C<$ctx> instead of the usual
+C<$c>. The reason is simple: It's an opinionated best practice, since C<$ctx>
+stands out more.
+
 =head2 Setting a Path Part
 
 As usual with Catalyst actions, the path part (the public name of this part of
@@ -529,8 +545,8 @@ specify an action after a C<E<lt>-> following the action name:
 =head2 Arguments
 
 You can use signatures like you are use to from L<MooseX::Method::Signatures>
-to declare action parameters. The number of arguments will be used during 
-dispatching. Dispatching by type constraint is planned but not yet implemented.
+to declare action parameters. The number of positinoal arguments will be used 
+during dispatching as well as their types.
 
 The signature follows the action name:
 
@@ -562,11 +578,25 @@ an array as a variable:
 
 =head2 Validation
 
-Currently, when the arguments do not fit the signature because of a L<Moose>
-validation error, the response body will be set to C<Not found> and the
-status to C<404>. This only applies when debug mode is off. If it is turned on,
-the error message will be prefixed with C<BAD REQUEST: >. The action will 
-automatically detach after a failed signature validation.
+The signatures are now validated during dispatching-time, and an action with
+a non-matching signature (number of positional arguments and their types) will
+not be dispatched to. This means that
+
+    action base under '/' as '';
+
+    under base {
+
+        final as double, action double_string (Str $x) {
+            $ctx->response->body( $x x 2 );
+        }
+
+        final as double, action double_integer (Int $x) {
+            $ctx->response->body( $x * 2 );
+        }
+    }
+
+will return C<foofoo> when called as C</double/foo> and C<46> when called as
+C</double/23>.
 
 =head2 Actions and Method Modifiers
 
@@ -606,6 +636,25 @@ consume the C<RichBase> role declared above:
         }
     }
 
+=head2 Action Classes
+
+B<This option is even more experimental>
+
+You might want to create an action with a different class than the usual
+L<Catalyst::Action>. A usual suspect here is L<Catalyst::Action::RenderView>.
+You can use the C<isa> option (did I mention it's experimental?) to specify
+what class to use:
+
+    controller MyApp::Web::Controller::Root {
+
+        $CLASS->config(namespace => '');
+
+        action end isa RenderView;
+    }
+
+The loaded class will be L<Moose>ified, so we are able to apply essential
+roles.
+
 =head1 ROLES
 
 =over
